@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Foundation and Contributors.
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -12,28 +12,25 @@
 ##############################################################################
 """ CMFDefault portal_metadata tool.
 
-$Id: MetadataTool.py 110659 2010-04-08 15:54:42Z tseaver $
+$Id: MetadataTool.py 106324 2009-12-09 11:33:33Z jens $
 """
 
-from AccessControl import ClassSecurityInfo
-from Globals import DTMLFile
-from Globals import InitializeClass
-from Globals import PersistentMapping
+from AccessControl.SecurityInfo import ClassSecurityInfo
+from App.class_init import InitializeClass
+from App.special_dtml import DTMLFile
 from OFS.Folder import Folder
 from OFS.SimpleItem import SimpleItem
+from Persistence import PersistentMapping
 from zope.interface import implements
 
 from Products.CMFCore.interfaces import IMetadataTool
-from Products.CMFCore.interfaces.portal_metadata \
-        import portal_metadata as z2IMetadataTool
 from Products.CMFCore.utils import registerToolInterface
 from Products.CMFCore.utils import UniqueObject
-
-from exceptions import MetadataError
-from permissions import ManagePortal
-from permissions import ModifyPortalContent
-from permissions import View
-from utils import _dtmldir
+from Products.CMFDefault.exceptions import MetadataError
+from Products.CMFDefault.permissions import ManagePortal
+from Products.CMFDefault.permissions import ModifyPortalContent
+from Products.CMFDefault.permissions import View
+from Products.CMFDefault.utils import _dtmldir
 
 
 class MetadataElementPolicy( SimpleItem ):
@@ -327,7 +324,7 @@ class MetadataSchema( SimpleItem ):
         """
         # Don't replace.
         if self.element_specs.has_key( element ):
-           return
+            return
 
         self.element_specs[ element ] = ElementSpec( is_multi_valued )
 
@@ -374,37 +371,10 @@ _DCMI_ELEMENT_SPECS = ( ( 'Title', 0 )
 class MetadataTool(UniqueObject, Folder):
 
     implements(IMetadataTool)
-    __implements__ = (z2IMetadataTool, )
 
     id = 'portal_metadata'
     meta_type = 'Default Metadata Tool'
 
-    _DCMI = None
-    def _get_DCMI( self ):
-
-        if self._DCMI is None:
-            dcmi = self._DCMI = MetadataSchema( 'DCMI', _DCMI_ELEMENT_SPECS )
-
-            old_specs = getattr( self, 'element_specs', None )
-            if old_specs is not None:
-                del self.element_specs
-                for element_id, old_spec in old_specs.items():
-                    new_spec = dcmi.getElementSpec( element_id )
-                    for typ, policy in old_spec.listPolicies():
-                        if typ is not None:
-                            new_spec.addPolicy( typ )
-                        tp = new_spec.getPolicy( typ )
-                        tp.edit( is_required=policy.isRequired()
-                               , supply_default=policy.supplyDefault()
-                               , default_value=policy.defaultValue()
-                               , enforce_vocabulary=policy.enforceVocabulary()
-                               , allowed_vocabulary=policy.allowedVocabulary()
-                               )
-
-        return self._DCMI
-
-    DCMI = property(_get_DCMI, None)
-
     #
     #   Default values.
     #
@@ -414,7 +384,8 @@ class MetadataTool(UniqueObject, Folder):
 
     def __init__( self, publisher=None ):
 
-        self.editProperties( publisher )
+        self.editProperties(publisher)
+        self.DCMI = MetadataSchema('DCMI', _DCMI_ELEMENT_SPECS)
 
     #
     #   ZMI methods
