@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Foundation and Contributors.
+# Copyright (c) 2004 Zope Corporation and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -12,10 +12,10 @@
 ##############################################################################
 """ CMFDefault setup handlers.
 
-$Id: setuphandlers.py 110659 2010-04-08 15:54:42Z tseaver $
+$Id: setuphandlers.py 94390 2008-12-27 21:48:36Z tseaver $
 """
 
-from exceptions import BadRequest
+from Products.CMFDefault.exceptions import BadRequest
 
 
 def importVarious(context):
@@ -24,14 +24,22 @@ def importVarious(context):
     This provisional handler will be removed again as soon as full handlers
     are implemented for these steps.
     """
+    logger = context.getLogger('various')
+
+    # Only run step if a flag file is present
+    if context.readDataFile('various.txt') is None:
+        logger.debug('Nothing to import.')
+        return
+
     site = context.getSite()
 
     try:
         site.manage_addPortalFolder('Members')
+        site.Members.manage_addProduct['OFSP'].manage_addDTMLMethod(
+                          'index_html', 'Member list', '<dtml-return roster>')
+        logger.info('Members folder imported.')
     except BadRequest:
-        return 'Various settings: Nothing to import.'
-    site.Members.manage_addProduct['OFSP'].manage_addDTMLMethod('index_html',
-                                        'Member list', '<dtml-return roster>')
-    site.acl_users.encrypt_passwords = False
+        logger.warning('Importing Members folder failed.')
 
-    return 'Various settings from PortalGenerator imported.'
+    site.acl_users.encrypt_passwords = False
+    logger.info('Password encryption disabled.')
