@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Foundation and Contributors.
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -12,13 +12,14 @@
 ##############################################################################
 """ Unit tests for MetadataTool module.
 
-$Id: test_MetadataTool.py 110659 2010-04-08 15:54:42Z tseaver $
+$Id: test_MetadataTool.py 106324 2009-12-09 11:33:33Z jens $
 """
 
 import unittest
 import Testing
 
 from Acquisition import aq_base
+from zope.interface.verify import verifyClass
 
 
 class TestMetadataElementPolicy(unittest.TestCase):
@@ -139,15 +140,7 @@ class TestMetadataTool(unittest.TestCase):
 
         return Foo(), Bar()
 
-    def test_z2interfaces(self):
-        from Interface.Verify import verifyClass
-        from Products.CMFCore.interfaces.portal_metadata \
-                import portal_metadata as IMetadataTool
-
-        verifyClass(IMetadataTool, self._getTargetClass())
-
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from Products.CMFCore.interfaces import IMetadataTool
 
         verifyClass(IMetadataTool, self._getTargetClass())
@@ -487,46 +480,6 @@ class TestMetadataTool(unittest.TestCase):
         tool.removeSchema( 'Arbitrary' )
         self.assertRaises( KeyError, tool.removeSchema, 'Arbitrary' )
 
-    def test_migration( self ):
-        # Test that we forward-migrate old-style DCMI policies.
-        from Products.CMFDefault.MetadataTool import ElementSpec
-
-        tool = self._makeOne()
-        tool.element_specs = { 'Title' : ElementSpec( 0 )
-                             , 'Description' : ElementSpec( 0 )
-                             , 'Subject' : ElementSpec( 1 )
-                             , 'Format' : ElementSpec( 0 )
-                             , 'Language' : ElementSpec( 0 )
-                             , 'Rights' : ElementSpec( 0 )
-                             }
-        subj = tool.element_specs[ 'Subject' ]
-        subj.addPolicy( 'Foo' )
-        subj.getPolicy( 'Foo' ).edit( False
-                                    , False
-                                    , None
-                                    , True
-                                    , ( 'bar', 'baz' )
-                                    )
-
-        dcmi = tool.DCMI
-
-        self.assertEqual( dcmi.getId(), 'DCMI' )
-
-        # Accessing the DCMI property converts and clears 'element_specs'
-        self.assertRaises(AttributeError, lambda: tool.element_specs )
-
-        subj2 = dcmi.getElementSpec( 'Subject' )
-        subj_default = subj2.getPolicy( None )
-        subj_foo = subj2.getPolicy( 'Foo' )
-
-        self.assertEqual( subj_foo.isRequired(), False )
-        self.assertEqual( subj_foo.supplyDefault(), False )
-        self.assertEqual( subj_foo.defaultValue(), None )
-        self.assertEqual( subj_foo.enforceVocabulary(), True )
-        self.assertEqual( len( subj_foo.allowedVocabulary() ), 2 )
-        self.failUnless( 'bar' in subj_foo.allowedVocabulary() )
-        self.failUnless( 'baz' in subj_foo.allowedVocabulary() )
-
 
 def test_suite():
     return unittest.TestSuite((
